use-wordpress-block
WordPress block metadata primitives for RustUse.
Experimental
use-wordpress-block is experimental while use-php remains below 0.3.0.
Example
use use_wordpress_block::{WordPressBlockJson, WordPressBlockName};
let block = WordPressBlockJson::new(WordPressBlockName::new("acme/book-card")?);
assert_eq!(block.name().as_str(), "acme/book-card");Scope
block.json-oriented block names, categories, attributes, supports, and asset path labels.
Non-goals
- JavaScript, Gutenberg runtime behavior, block rendering, or asset building.
License
Licensed under either Apache-2.0 or MIT.
Structs
- Word
Press Block Asset Path - Word
Press Block Attribute - WordPress block attribute metadata.
- Word
Press Block Attribute Name - Word
Press Block Category - Word
Press Block Json - WordPress
block.json-oriented metadata. - Word
Press Block Name - WordPress block name metadata in
namespace/blockform.
Enums
- Word
Press Block Attribute Type - WordPress block attribute type metadata.
- Word
Press Block Error - Error returned when WordPress block metadata is invalid.
- Word
Press Block Support - WordPress block support metadata.